
# R code chunk 58
coho<-read.csv("http://www.public.iastate.edu/~mcolvin/575x/coho.csv")

pairs(coho[,c(3:8)])
summary(coho)

coho.global<- lm(log(cohoDensity)~ streamId + maxTemp +naturalCover+slope+percentPool+riparianCover,coho)

# LETS EVALUATE SOME HYPOTHESES
M1<-lm(log(cohoDensity)~1,coho)
M2<-lm(log(cohoDensity)~1,coho)
M3<-lm(log(cohoDensity)~1,coho)
M4<-lm(log(cohoDensity)~1,coho)
M5<-lm(log(cohoDensity)~1,coho)
M6<-lm(log(cohoDensity)~1,coho)
M7<-lm(log(cohoDensity)~1,coho)
M8<-lm(log(cohoDensity)~1,coho)
M9<-lm(log(cohoDensity)~1,coho)
M10<-lm(log(cohoDensity)~1,coho)

# MAKE A DATAFRAME WITH MODEL AIC
selectionTable <- data.frame(
	model=c("global",paste("M",1:10,sep="")),
	aic=c(AIC(coho.global),AIC(M1),AIC(M2),AIC(M3), AIC(M4),AIC(M5),
	AIC(M6),AIC(M7),AIC(M8),AIC(M9),AIC(M10)))

# CALCULATE THE AIC DIFFERENCE (DELTA AIC)
selectionTable$deltaAic<-selectionTable$aic- min(selectionTable$aic)

# CALCULATE THE MODEL LIKELIHOOD
selectionTable$lik<-exp(-0.5*selectionTable$deltaAic)

# CALCULATE THE RELATIVE MODEL WEIGHT
selectionTable$weight<-selectionTable$lik/sum(selectionTable$lik)

# REORDER THE DATAFRAME BY AIC (FOR EASE OF INTERPRETATION)
selectionTable<-selectionTable[order(selectionTable$aic),]

# LOOK AT THE SELECTION RESULTS
selectionTable

# R code chunk 59
# PLOTTING A SHAPEFILE USING THE MAPTOOLS PACKAGE
setwd("C:/contEdCourseData/extras")
# install.packages("maptools")
require(maptools)
clearLake<- readShapePoly("./clearlakenad83.shp",proj4string=CRS("+proj=utm
+zone=15 +datum=NAD83"))
plot(clearLake,axes=T, las=1)
par(mar=c(5,5,1,1))
plot(clearLake,axes=T, las=1)
# LETS GET SOME POINTS TO PUT ON THE MAP
trawling<-read.csv("./trawl.csv")
points( startUTMy~startUTMx, trawling)
# IT IS A LAKE, LETS MAKE IT BLUE
plot(clearLake,axes=T, las=1, col="blue")
points(startUTMy~startUTMx, trawling,pch=16)
savePlot("./trawlSites",type="pdf")

# R code chunk 60
# AN AGE OR STAGE MATRIX OF FECUNDITIES AND SURVIVALS
A<- matrix(c( 0,2,3,4, 0.1,0,0,0, 0,0.3,0,0, 0,0,0.4,0),nrow=4, byrow=T)
# A MATRIX TO HOLD THE FORECASTS OF THE POP
population<- matrix(0, nrow=4, ncol=100)
# SEED THE POPULATION
population[,1]<- c(400, 200, 100, 40)
# FORECAST THE STRUCTURED POPULATION
for(i in 2:100){
population[,i]<- A%*%population[,i-1]}
# CALCULATE THE TOTAL POPULATION AT EACH TIME STEP
totalPopulation<- apply(population, 2, sum)
plot(totalPopulation)
# LAMBDA FOR MATRIX A
lambda<-as.numeric(eigen(A)$values[1])
w<-as.numeric(eigen(A)$vectors[,1]);
w<-w/sum(w); # STABLE AGE DISTRIBUTATION FOR MATRIX A
v<-as.numeric(eigen(t(A))$vectors[,1]);
v<-v/v[1]; # REPRODUCTIVE VALUE FOR MATRIX A
s<-outer(v,w)/sum(v*w); # SENSITIVITY FOR MATRIX A
e<-(s*A)/lambda # ELASTICITIES FOR MATRIX A

# R code chunk 61
##### For loops are good for doing repetitive calculations
values<- list(x=rep(0,100)) # makes a list to hold the values
names(values) # values within the list we can add values to
values # look at the list
for(i in 1:100){
values$x[i]<- values$x[i]+rnorm(1,0,0.2) # Add a random number with mean 0
}
values$x